@@ -61,6 +61,10 @@ parser.add_argument("-c", "--config",
                     dest="config",
                     help="Start configuration of acido.",
                     action='store_true')
+parser.add_argument("-cp", "--copy",
+                    dest="copy",
+                    help="Copy remote file.",
+                    action='store_true')
 parser.add_argument("-ps", "--interactive",
                     dest="interactive",
                     help="Start interactive acido session.",
@@ -99,7 +103,7 @@ def exec_command(rg, cg, cont, command, max_retries):
     retries = 0
     failed = False
 
-    while 'Done' not in output or 'Exit' not in output:
+    while 'Done' not in output:
 
         retries += 1
 
@@ -111,29 +115,32 @@ def exec_command(rg, cg, cont, command, max_retries):
         subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
         time.sleep(5)
         output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env).decode()
-        print(output)
 
+        if 'Exit' in output:
+            failed = True
+            break
         if 'Done' in output:
+            failed = False
             break
 
     if not failed:
         subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
         time.sleep(2)
-        subprocess.Popen(["tmux", "send-keys", "-t", cont, "(cat temp) > output", "Enter", "Enter"], env=env)
-        time.sleep(5)
-        subprocess.Popen(["tmux", "send-keys", "-t", cont, "cat output", "Enter"], env=env)
+        subprocess.Popen(["tmux", "send-keys", "-t", cont, "cat temp", "Enter", "Enter"], env=env)
         time.sleep(10)
         subprocess.Popen(["tmux", "send-keys", "-t", cont, "Enter"], env=env)
         time.sleep(2)
-
         try:
             output = subprocess.check_output(["tmux", "capture-pane", "-pt", cont], env=env)
             output = output.decode()
-            print(output)
+            command_uuid = output.split('command: ')[1].split('\n')[0].strip()
+            print(command_uuid)
         except Exception as e:
-            output = None
+            command_uuid = None
             print(bad(f'Error capturing output from: {bold(cont)}'))
-
+    else:
+        command_uuid = None
+        print(bad(f'Exception ocurred while executing "{command}" from: {bold(cont)}'))
 
     # Kill shell
     subprocess.Popen(["tmux", "send-keys", "-t", cont, "(rm temp && rm output && exit)", "Enter"], env=env)
@@ -141,7 +148,7 @@ def exec_command(rg, cg, cont, command, max_retries):
     # Kill tmux window
     subprocess.Popen(["tmux", "kill-session", "-t", cont], env=env)
 
-    return cont, output
+    return cont, command_uuid
 
 class Acido(object):
 
@@ -333,7 +340,7 @@ class Acido(object):
         return
 
     def save_output(self, command: list = None):
-        output = subprocess.check_output(command, shell=True)
+        output = subprocess.check_output(command.split(' '))
         file, filename = self.blob_manager.upload(
             output
         )
@@ -341,10 +348,10 @@ class Acido(object):
             print(good(f'Executed command: {filename}'))
         return output
     
-    def load_input(self, command_uuid: str = None, filename: str = 'input.txt'):
+    def load_input(self, command_uuid: str = None, filename: str = 'input.txt', write_to_file: bool = False):
         if command_uuid:
             input_file = self.blob_manager.download(command_uuid)
-            if input_file:
+            if write_to_file:
                 print(good(f'Downloaded file: {command_uuid}'))
                 open(filename, 'wb').write(input_file)
                 print(good(f'Input written to: {filename}'))
@@ -375,6 +382,7 @@ class Acido(object):
         results = [result.wait() for result in results]
 
         for c, o in instances_outputs.items():
+            o = self.load_input(o)
             if o:
                 print(good(f'Executed command on {bold(c)}. Output: [\n{o}\n]'))
             else:
@@ -415,7 +423,6 @@ if __name__ == "__main__":
     if args.select:
         acido.select(selection=args.select, interactive=bool(args.interactive))
     if args.exec_cmd:
-        print(args.exec_cmd)
         pool = ThreadPool(processes=30)
         acido.exec(command=args.exec_cmd)
     if args.remove:
